@@ -13,6 +13,7 @@ use serde::{de::Deserialize, de::DeserializeOwned, Serialize};
 use binary_rw::{BinaryReader, BinaryWriter, Endian, MemoryStream};
 
 pub use {deserializer::Deserializer, error::Error, serializer::Serializer};
+pub use binary_rw;
 
 /// Result type for serialization and deserialization.
 pub type Result<T> = std::result::Result<T, Error>;
@@ -323,6 +324,8 @@ mod tests {
         Ok(())
     }
 
+    const MAGIC: [u8; 4] = [84, 79, 68, 79];
+
     #[derive(Debug, Eq, PartialEq)]
     struct TodoList {
         magic: [u8; 4],
@@ -332,7 +335,7 @@ mod tests {
     impl Default for TodoList {
         fn default() -> Self {
             Self {
-                magic: [84, 79, 68, 79],
+                magic: MAGIC,
                 todos: vec![],
             }
         }
@@ -348,11 +351,12 @@ mod tests {
 
     impl Decode for TodoList {
         fn decode(&mut self, de: &mut Deserializer) -> super::Result<()> {
-            self.magic = de.reader.read_bytes(4)?.as_slice().try_into()
-                .map_err(|_| {
-                    Error::Message(
-                        "cannot convert magic bytes to slice".to_string())
-                })?;
+            self.magic = de.reader.read_bytes(4)?.as_slice().try_into()?;
+            if self.magic != MAGIC {
+                return Err(
+                    Error::Message("not a todo list binary file".to_string()));
+            }
+
             self.todos = Deserialize::deserialize(de)?;
             Ok(())
         }
